		LIST	P=PIC12F629
		__CONFIG 0x3FC6
		RADIX	DEC
;
; Annoy-O-Matic Program By Bob Diaz, April 1, 2007
; Version 1_1 Timing Improvements, Shorter Delays, June 1, 2007
; Version 1_2 Sound Improvements,  Added Extra Tones, Novemebr 9, 2007
; Version 1_3 Additional Timing Improvements, Even Shorter Delays, September 12, 2008
; 

; Standard equates used in programs for 12F629 or 12F675

W			EQU		0			; W Register
F			EQU		1			; F Registers
INDF		EQU		0x00		; The Indirect Register
Option_Reg	EQU		0x01		; Option Register in Bank 1
PCL			EQU		0x02		; Program Counter, Low Byte
Status		EQU		0x03		; Status Register
FSR			EQU		0x04		; File Select Register
C			EQU		0			; Carry Flag bit position
Z			EQU		2			; Zero Flag bit position
RP0			EQU		5			; Bank Selection bit position
GPIO		EQU		0x05		; All I/O Pins
PCLATH		EQU		0x0A		; Program Counter, High Byte
OSCCAL		EQU		0x10		; Osc control
EEDATA		EQU		0x1A		; EEPROM Data
EEADR		EQU		0x1B		; EEPROM Address
EECON1		EQU		0x1C		; EEPROM Control Register 1
ADCON0		EQU		0x1F		; A/D Converter, 12F675
ANSEL		EQU		0x1F		; A/D Converter, 12F675
WPU			EQU		0x15		; Weak Pull up resistor selection
CMCON		EQU		0x19		; Comparator Control

; I/O Pin Definations
Pin_Pause		EQU		2		; When pin goes low, stop the clock
Pin_Test		EQU		3		; Force 10 second count for testing
Pin_Fast		EQU		4		; Shorten the delay by 256x for testing

; RAM Definations
Count1			EQU		32		; Outer Loop for delay count
Count2			EQU		33		; Middle Loop, makes 10 second delays
Count3			EQU		34		; Inner Loop, makes 1/8 second delays
Pointer1		EQU		35		; Random number pointer #1
Pointer2		EQU		36		; Random number pointer #2
Temp			EQU		37		; Holds a copy of pointer 1 or 2
Number1			EQU		38		; Number from random pointer 1
Number2			EQU		39		; Number from random pointer 2

;
; The code starts here
;
		ORG		0x000
Start
		BSF			Status, RP0	; Select Bank 1

		CLRWDT
		MOVLW		b'01011111'	; Set up options
		MOVWF		Option_Reg

		MOVLW		b'11111111'	; Activate pull up resistors
		MOVWF		WPU

		MOVLW		b'111111'		; Select input and output pins
		MOVWF		GPIO			; All pins are set as inputs

		BCF			ANSEL, 0		; All pins digital I/O

		BCF			Status, RP0	; Select Bank 0

		MOVLW		b'11111111'	; Turn off the Comparator
		MOVWF		CMCON 

		BCF			ADCON0, 0		; Shut Off A/D Converter, 12F675

		MOVLW		0xFF			; All outputs will start high
		MOVWF		GPIO

;
; The set-up done, the MAIN code goes below...
; *************** MAIN CODE STARTS ***************
;

Main_Start
;
; Random Number Routine
;
		INCFSZ		Pointer1, F	; Point to the next random number

		DECF		Pointer2, F	; This Poinmter is decremented,
								; EXCEPT when the Pointer1 is = 0

		MOVF		Pointer1, W	; Get First Random Number
		CALL		Get_Random
		MOVWF		Number1

		MOVF		Pointer2, W	; Get Second Random Number
		CALL		Get_Random
		MOVWF		Number2

		SWAPF		Number2, W	; Swap the nibbles & put in W
		XORLW		0xA5			; Invert 1/2 the bits

		SUBWF		Number1, W	; Use the 2 numbers to make random #
		ANDLW		b'01111111'	; Limit from 0 to 127

; Make sure the minimum time is 6 minutes (72 x 2.5 seconds = 180 seconds)
		ADDLW		72			; Force a minimum of 3 minutes delay

; Count1 is the delay time, it ranges from 72 (3 minutes) to 199 (8.29 minutes)
		BTFSS		GPIO, Pin_Test	; If GND, do 10 Second delays
		MOVLW		4			; Set for single 10 second wait
		MOVWF		Count1

; Start the Delay Time
Loop1
		MOVLW		20			; Delay for 2.5 seconds
		MOVWF		Count2

Loop2
		CLRF		Count3		; Do this 256 times
								; Loop3 delays for 1/8 second

; If Pin2, GP5 is grounded, Skip the 1024 cycle delay. 
; This speeds up the times for each delay for testing.
		BTFSS		GPIO, Pin_Fast
		GOTO		Pause_Test

Loop3
		NOP						; Kills 1024 cycles of time
		DECFSZ		Count3, F
		GOTO		Loop3		; Inner Loop End

Pause_Test
		BTFSS		GPIO , Pin_Pause	; Stop the Clock?
		GOTO		Pause_Test		; Pin5, GP2 is grounded, Jump Back

		DECFSZ		Count2, F
		GOTO		Loop2

		DECFSZ		Count1, F
		GOTO		Loop1

; Times's up, now Switch on outputs and beep
		BSF			Status, RP0	; Select Bank 1

		MOVLW		b'111100'		; Select Speaker as output pins
		MOVWF		GPIO	

		BCF			Status, RP0	; Select Bank 0

		CALL		Chirp_H		;   2K Hz,  For 60 Cycles

		CALL		Chirp_L		; 1.5K Hz,  For 40 Cycles

		CALL		Chirp_L		; 1.5K Hz,  For 40 Cycles

;		CALL		Chirp_H		;   2K Hz,  For 60 Cycles

		MOVLW		0xFF			; All outputs set high
		MOVWF		GPIO

; Sound is done, switch speaker outputs to inputs
		BSF			Status, RP0	; Select Bank 1

		MOVLW		b'111111'		; Select all pins as input pins
		MOVWF		GPIO

		BCF			Status, RP0	; Select Bank 0

		GOTO		Main_Start




;
;  Subroutine: Get_Random, Gets a random number from a 256 byte lookup table
;              On entry, W points to table location
;              On exit,  W contains number from table
;
Get_Random
		MOVWF	Temp			; Save the pointer
		MOVLW	0x02			; High Byte of lookup table (0x0200 - 0x02FF)
		MOVWF	PCLATH		; Point to High Byte of table
		MOVF	Temp, W		; Get Pointer
		MOVWF	PCL			; Instruction = GOTO  PCLATH, PCL




;
; Subroutine: Make A 2 kHz Sound, 60 cycles long
;

Chirp_H
		MOVLW		b'01'		;  1 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		;  2 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		;  3 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		;  4 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		;  5 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		;  6 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		;  7 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		;  8 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		;  9 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 10 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 11 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 12 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 13 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 14 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 15 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 16 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 17 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 18 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 19 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 20 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 21 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 22 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 23 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 24 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 25 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 26 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 27 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 28 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 29 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 30 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 31 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 32 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 33 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 34 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 35 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 36 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 37 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 38 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 39 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 40 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 41 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 42 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 43 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 44 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 45 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 46 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 47 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 48 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 49 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 50 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 51 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 52 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 53 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 54 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 55 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 56 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 57 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 58 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 59 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 60 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		RETURN







;
; Random Time Lookup Table (256 numbers)
;
		ORG		0x0200
Random
		RETLW	230
		RETLW	143
		RETLW	27
		RETLW	209
		RETLW	156
		RETLW	148
		RETLW	233
		RETLW	172
		RETLW	8
		RETLW	66
		RETLW	92
		RETLW	90
		RETLW	78
		RETLW	249
		RETLW	2
		RETLW	31
		RETLW	56
		RETLW	85
		RETLW	216
		RETLW	77
		RETLW	11
		RETLW	184
		RETLW	104
		RETLW	57
		RETLW	239
		RETLW	36
		RETLW	50
		RETLW	117
		RETLW	242
		RETLW	65
		RETLW	240
		RETLW	201
		RETLW	237
		RETLW	59
		RETLW	229
		RETLW	247
		RETLW	39
		RETLW	225
		RETLW	108
		RETLW	142
		RETLW	193
		RETLW	111
		RETLW	25
		RETLW	214
		RETLW	173
		RETLW	21
		RETLW	161
		RETLW	251
		RETLW	171
		RETLW	154
		RETLW	3
		RETLW	222
		RETLW	159
		RETLW	62
		RETLW	160
		RETLW	135
		RETLW	34
		RETLW	226
		RETLW	246
		RETLW	243
		RETLW	120
		RETLW	113
		RETLW	157
		RETLW	149
		RETLW	103
		RETLW	40
		RETLW	145
		RETLW	38
		RETLW	202
		RETLW	248
		RETLW	235
		RETLW	67
		RETLW	73
		RETLW	210
		RETLW	102
		RETLW	83
		RETLW	197
		RETLW	47
		RETLW	93
		RETLW	20
		RETLW	76
		RETLW	116
		RETLW	164
		RETLW	227
		RETLW	49
		RETLW	255
		RETLW	115
		RETLW	53
		RETLW	94
		RETLW	175
		RETLW	37
		RETLW	100
		RETLW	68
		RETLW	250
		RETLW	15
		RETLW	101
		RETLW	41
		RETLW	215
		RETLW	129
		RETLW	46
		RETLW	112
		RETLW	166
		RETLW	79
		RETLW	44
		RETLW	200
		RETLW	252
		RETLW	192
		RETLW	232
		RETLW	221
		RETLW	236
		RETLW	207
		RETLW	81
		RETLW	238
		RETLW	96
		RETLW	169
		RETLW	70
		RETLW	137
		RETLW	254
		RETLW	80
		RETLW	146
		RETLW	198
		RETLW	97
		RETLW	110
		RETLW	133
		RETLW	183
		RETLW	14
		RETLW	118
		RETLW	1
		RETLW	165
		RETLW	84
		RETLW	18
		RETLW	244
		RETLW	126
		RETLW	182
		RETLW	48
		RETLW	95
		RETLW	144
		RETLW	234
		RETLW	253
		RETLW	89
		RETLW	147
		RETLW	63
		RETLW	204
		RETLW	196
		RETLW	60
		RETLW	189
		RETLW	4
		RETLW	213
		RETLW	69
		RETLW	199
		RETLW	208
		RETLW	74
		RETLW	23
		RETLW	152
		RETLW	168
		RETLW	220
		RETLW	105
		RETLW	153
		RETLW	10
		RETLW	187
		RETLW	5
		RETLW	139
		RETLW	155
		RETLW	106
		RETLW	71
		RETLW	51
		RETLW	205
		RETLW	32
		RETLW	28
		RETLW	176
		RETLW	167
		RETLW	179
		RETLW	138
		RETLW	19
		RETLW	203
		RETLW	132
		RETLW	42
		RETLW	194
		RETLW	141
		RETLW	86
		RETLW	22
		RETLW	219
		RETLW	181
		RETLW	124
		RETLW	140
		RETLW	241
		RETLW	218
		RETLW	162
		RETLW	58
		RETLW	55
		RETLW	228
		RETLW	45
		RETLW	190
		RETLW	33
		RETLW	191
		RETLW	30
		RETLW	64
		RETLW	211
		RETLW	177
		RETLW	0
		RETLW	206
		RETLW	109
		RETLW	170
		RETLW	174
		RETLW	98
		RETLW	6
		RETLW	185
		RETLW	26
		RETLW	61
		RETLW	9
		RETLW	24
		RETLW	13
		RETLW	151
		RETLW	186
		RETLW	188
		RETLW	150
		RETLW	245
		RETLW	7
		RETLW	35
		RETLW	122
		RETLW	82
		RETLW	119
		RETLW	43
		RETLW	136
		RETLW	158
		RETLW	99
		RETLW	217
		RETLW	231
		RETLW	130
		RETLW	52
		RETLW	212
		RETLW	29
		RETLW	136
		RETLW	107
		RETLW	178
		RETLW	128
		RETLW	91
		RETLW	125
		RETLW	16
		RETLW	87
		RETLW	72
		RETLW	134
		RETLW	195
		RETLW	123
		RETLW	114
		RETLW	54
		RETLW	224
		RETLW	12
		RETLW	121
		RETLW	75
		RETLW	17
		RETLW	180
		RETLW	88
		RETLW	131
		RETLW	127
		RETLW	204


;
; Subroutine: Make A 1.5 kHz Sound, 40 cycles long
;

Chirp_L
		MOVLW		b'01'		;  1 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		;  2 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		;  3 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		;  4 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		;  5 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		;  6 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		;  7 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		;  8 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		;  9 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		; 10 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		; 11 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		; 12 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		; 13 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		; 14 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		; 15 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		; 16 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		; 17 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		; 18 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		; 19 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		; 20 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		; 21 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 22 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		; 23 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		; 24 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		; 25 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		; 26 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		; 27 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		; 28 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		; 29 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		; 30 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		; 31 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		; 32 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		; 33 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		; 34 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		; 35 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		; 36 Cycle Sound
		MOVWF		GPIO
		MOVLW		b'10'
		MOVWF		GPIO

		MOVLW		b'01'		; 37 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		; 38 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		; 39 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		MOVLW		b'01'		; 40 Cycle Sound
		MOVWF		GPIO
		NOP
		MOVLW		b'10'
		MOVWF		GPIO
		NOP

		RETURN

;
; Define EEPROM Data, Not required, but nice to put in...
;
		ORG		0x2100
		DE		"Annoy-O-Matic By Bob Diaz, First Version, April 1, 2007, Version 1_3, September 12, 2008.",0,0

; The end of the CODE
		END
